==> gava-0.0.1-sources.jar: org/gonn/gava/Loggable.java <==
package org.gonn.gava;

import java.util.function.Supplier;

/**
 * Minimal Logger Interface
 *
 * @author Gon Yi
 * @link https://gonn.org
 * @version 1.0.1
 *
 * @param <T> Any value that supplier will return
 */
public interface Loggable<T> {
    // ====================================================================================================
    // LOGGING
    // Log message takes a supplier function to reduce allocation
    // ====================================================================================================
    void debug(Supplier<T> msg);
    void info(Supplier<T> msg);
    void warn(Supplier<T> msg);
    void error(Supplier<T> msg);

    // ====================================================================================================
    // OPTIONAL METHODS
    // Since trace and fatal aren't used often, it is not necessary to define it.
    // But, if those are used without being defined, the nearest method will be called.
    // (e.g. trace -> debug, fatal -> error)
    // for error and fatal methods, `int skip` is for skipping callers (stack)
    // ====================================================================================================
    default void trace(Supplier<T> msg) {this.debug(msg);}
    default void fatal(Supplier<T> msg) {this.error(msg);}
    
    // OPTIONAL: SKIP STACK
    default void warn(Supplier<T> msg, int skip) {this.warn(msg);}
    default void error(Supplier<T> msg, int skip) {this.error(msg);}
    default void fatal(Supplier<T> msg, int skip) {this.fatal(msg);}
}

==> gava-0.0.2-sources.jar: org/gonn/gava/Loggable.java <==
/*
 * <https://gonn.org> [++]
 * Copyright (c) 2023 Gon Yi. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 */
package org.gonn.gava;

/**
 * Minimal Logger Interface
 *
 * @param <T> Any value that supplier will return
 * @author Gon Yi
 * @version 1.0.1
 * @see <a href="https://gonn.org">gonn.org</a>
 */
public interface Loggable<T> {
    // ====================================================================================================
    // LOGGING
    // Log message takes a supplier function to reduce allocation
    // ====================================================================================================
    void debug(FnR<T> msg);

    void info(FnR<T> msg);

    void warn(FnR<T> msg);

    void error(FnR<T> msg);

    // ====================================================================================================
    // OPTIONAL METHODS
    // Since trace and fatal aren't used often, it is not necessary to define it.
    // But, if those are used without being defined, the nearest method will be called.
    // (e.g. trace -> debug, fatal -> error)
    // for error and fatal methods, `int skip` is for skipping callers (stack)
    // ====================================================================================================
    default void trace(FnR<T> msg) {
        this.debug(msg);
    }

    default void fatal(FnR<T> msg) {
        this.error(msg);
    }

    // OPTIONAL: SKIP STACK
    default void warn(FnR<T> msg, int skip) {
        this.warn(msg);
    }

    default void error(FnR<T> msg, int skip) {
        this.error(msg);
    }

    default void fatal(FnR<T> msg, int skip) {
        this.fatal(msg);
    }
}
